overrider_build is the sister crate to overrider, providing the build-time
bridge to allow intelligent conditional compilation.
Build example
overrider_build operates on the watch_files function:
fn main() {
overrider_build::watch_files(vec!["src/main.rs"]);
}Functions
- watch_
files - Scans a vector of files, constructing and handling the Cargo config flags that interface
with
overrider.